/* 
 * Copyright (C) 2004 the xine project
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: vis.h,v 1.6 2005/05/11 20:13:19 dsalt Exp $
 *
 * Visualisation wrapper code
 */

#ifndef HAVE_VIS_H
#define HAVE_VIS_H

#include <gtk/gtkradioaction.h>

#include "gtkvideo.h"

#define vis_hide(V,A) gtk_video_set_vis ((V), (A), FALSE)
gboolean vis_show (GtkVideo *, xine_audio_port_t **);
void vis_set (const char *);
void vis_cb (GtkRadioAction *, gpointer);

void vis_init (void);

#endif
